Module resolver

Module resolver 

Contains functions to resolve the value of a parameter given two other parameters

Modules

error
Contains error types Error types
nofailure
Offers computation functions that cannot fail, computation that necessitate a division are not supported Computation functions that cannot fail since they do not involve a division

Functions

gravity_from_height_and_impulse
Compute the gravity from the peak height and the vertical impulse
gravity_from_height_and_time
Compute the gravity from the peak height and the time to reach the peak
gravity_from_time_and_impulse
Compute the gravity from the time to reach the peak and the vertical impulse
height_from_impulse_and_gravity
Compute the peak height from the vertical impulse and the gravity
height_from_time_and_gravity
Compute the peak height from the time to reach the peak and the gravity
height_from_time_and_impulse
Compute the peak height from the time to reach the peak and the vertical impulse
impulse_from_height_and_gravity
Compute the vertical impulse from the peak height and the gravity
impulse_from_height_and_time
Compute the vertical impulse from the peak height and the time to reach the peak
impulse_from_time_and_gravity
Compute the vertical impulse from the time to reach the peak and the gravity
time_from_height_and_gravity
Compute time to reach the peak from the peak height and the gravity
time_from_height_and_impulse
Compute time to reach the peak from the peak height and the vertical impulse
time_from_impulse_and_gravity
Compute time to reach the peak from the vertical impulse and the gravity
time_from_speed_and_range
Compute the time to reach the peak from the horizontal speed and the range
time_from_speed_and_range_with_ratio
Compute the time to reach the peak from the horizontal speed, the range and an arbitrary ratio