Contains functions to resolve the value of a parameter given two other parameters
Modules
- error
- Contains error types Error types
- nofailure
- Offers computation functions that cannot fail, computation that necessitate a division are not supported Computation functions that cannot fail since they do not involve a division
Functions
- gravity_
from_ height_ and_ impulse - Compute the gravity from the peak height and the vertical impulse
- gravity_
from_ height_ and_ time - Compute the gravity from the peak height and the time to reach the peak
- gravity_
from_ time_ and_ impulse - Compute the gravity from the time to reach the peak and the vertical impulse
- height_
from_ impulse_ and_ gravity - Compute the peak height from the vertical impulse and the gravity
- height_
from_ time_ and_ gravity - Compute the peak height from the time to reach the peak and the gravity
- height_
from_ time_ and_ impulse - Compute the peak height from the time to reach the peak and the vertical impulse
- impulse_
from_ height_ and_ gravity - Compute the vertical impulse from the peak height and the gravity
- impulse_
from_ height_ and_ time - Compute the vertical impulse from the peak height and the time to reach the peak
- impulse_
from_ time_ and_ gravity - Compute the vertical impulse from the time to reach the peak and the gravity
- time_
from_ height_ and_ gravity - Compute time to reach the peak from the peak height and the gravity
- time_
from_ height_ and_ impulse - Compute time to reach the peak from the peak height and the vertical impulse
- time_
from_ impulse_ and_ gravity - Compute time to reach the peak from the vertical impulse and the gravity
- time_
from_ speed_ and_ range - Compute the time to reach the peak from the horizontal speed and the range
- time_
from_ speed_ and_ range_ with_ ratio - Compute the time to reach the peak from the horizontal speed, the range and an arbitrary ratio